==> clawiz-bpm-common-2.2.0-sources.jar: org/clawiz/bpm/common/metadata/data/process/flow/AbstractFlow.java <==
/*
 *
 *  * MIT License
 *  *
 *  * Copyright (c) 2018 Clawiz
 *  *
 *  * Permission is hereby granted, free of charge, to any person obtaining a copy
 *  * of this software and associated documentation files (the "Software"), to deal
 *  * in the Software without restriction, including without limitation the rights
 *  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  * copies of the Software, and to permit persons to whom the Software is
 *  * furnished to do so, subject to the following conditions:
 *  *
 *  * The above copyright notice and this permission notice shall be included in all
 *  * copies or substantial portions of the Software.
 *  *
 *  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  * SOFTWARE.
 *  *
 *
 */

package org.clawiz.bpm.common.metadata.data.process.flow;

import org.clawiz.bpm.common.metadata.data.process.node.AbstractProcessNode;
import org.clawiz.bpm.common.manager.instance.AbstractProcessInstance;
import org.clawiz.core.common.CoreException;
import org.clawiz.core.common.utils.reflection.ReflectionUtils;

import java.lang.reflect.Method;

public class AbstractFlow extends AbstractFlowPrototype {

    public AbstractProcessNode getSourceNode() {
        return (AbstractProcessNode) getParentNode();
    }

    public String getDescription() {
        return getDescription() != null ? getDescription() : getName();
    }

    private Method isAllowedMethod;
    public Method getIsAllowedMethod() {

        if ( isAllowedMethod == null ) {

            String methodName = "is" + getSourceNode().getJavaClassName() + getJavaClassName() + "Allowed";
            isAllowedMethod = ReflectionUtils.findMethod(getSourceNode().getProcess().getServiceClass(), methodName, AbstractProcessInstance.class);

            if ( isAllowedMethod == null) {
                throw new CoreException("Method ? for flow ? not found in process service class ?", methodName, getFullName(), getSourceNode().getProcess().getServiceClass().getName());
            }
        }
        return isAllowedMethod;
    }

    public String getFullJavaVariableName() {
        return getSourceNode().getFullJavaVariableName()
                + getJavaClassName();
    }

    public String getFullJavaClassName() {
        return getSourceNode().getFullJavaClassName()
                + getJavaClassName();
    }
}

==> clawiz-bpm-common-2.2.2-sources.jar: org/clawiz/bpm/common/metadata/data/process/flow/AbstractFlow.java <==
/*
 *
 *  * MIT License
 *  *
 *  * Copyright (c) 2018 Clawiz
 *  *
 *  * Permission is hereby granted, free of charge, to any person obtaining a copy
 *  * of this software and associated documentation files (the "Software"), to deal
 *  * in the Software without restriction, including without limitation the rights
 *  * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  * copies of the Software, and to permit persons to whom the Software is
 *  * furnished to do so, subject to the following conditions:
 *  *
 *  * The above copyright notice and this permission notice shall be included in all
 *  * copies or substantial portions of the Software.
 *  *
 *  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  * SOFTWARE.
 *  *
 *
 */

package org.clawiz.bpm.common.metadata.data.process.flow;

import org.clawiz.bpm.common.metadata.data.process.node.AbstractProcessNode;
import org.clawiz.bpm.common.manager.instance.AbstractProcessInstance;
import org.clawiz.core.common.CoreException;
import org.clawiz.core.common.utils.reflection.ReflectionUtils;

import java.lang.reflect.Method;

public class AbstractFlow extends AbstractFlowPrototype {

    public AbstractProcessNode getSourceNode() {
        return (AbstractProcessNode) getParentNode();
    }

    @Override
    public String getParentNodeFieldName() {
        return "outgoingFlows";
    }

    public String getDescription() {
        return getTargetNode().getDescription();
    }

    @Override
    public String getName() {
        if ( super.getName() != null ) {
            return super.getName();
        }
        return getTargetNode().getName();
    }

    private Method isAllowedMethod;
    public Method getIsAllowedMethod() {

        if ( isAllowedMethod == null ) {

            String methodName = "is" + getSourceNode().getJavaClassName() + getJavaClassName() + "Allowed";
            isAllowedMethod = ReflectionUtils.findMethod(getSourceNode().getProcess().getServiceClass(), methodName, AbstractProcessInstance.class);

            if ( isAllowedMethod == null) {
                throw new CoreException("Method ? for flow ? not found in process service class ?", methodName, getFullName(), getSourceNode().getProcess().getServiceClass().getName());
            }
        }
        return isAllowedMethod;
    }

    public String getFullJavaVariableName() {
        return getSourceNode().getFullJavaVariableName()
                + getJavaClassName();
    }

    public String getFullJavaClassName() {
        return getSourceNode().getFullJavaClassName()
                + getJavaClassName();
    }
}
